@@ -27,6 +27,13 @@ pub struct Parameter {
     pub hint: Option<DisplayHint>,
 }
 
+/// Precision of ISO8601 datetime
+#[derive(Clone, Debug, PartialEq)]
+pub enum TimePrecision {
+    Millis,
+    Seconds,
+}
+
 /// All display hints
 #[derive(Clone, Debug, PartialEq)]
 pub enum DisplayHint {
@@ -48,14 +55,25 @@ pub enum DisplayHint {
     Ascii,
     /// `:?`
     Debug,
-    /// `:µs`, formats integers as timestamps in microseconds
+    /// `:us`, formats integers as timestamps in microseconds
     Microseconds,
+    /// `:iso8601{ms,s}`, formats integers as timestamp in ISO8601 date time format
+    ISO8601(TimePrecision),
+    /// `__internal_bitflags_NAME` instructs the decoder to print the flags that are set, instead of
+    /// the raw value.
+    Bitflags {
+        name: String,
+        package: String,
+        disambiguator: String,
+    },
     /// Display hints currently not supported / understood
     Unknown(String),
 }
 
 /// Parses the display hint (e.g. the `#x` in `{=u8:#x}`)
 fn parse_display_hint(mut s: &str) -> Option<DisplayHint> {
+    const BITFLAGS_HINT_START: &str = "__internal_bitflags_";
+
     // The `#` comes before any padding hints (I think this matches core::fmt).
     // It is ignored for types that don't have an alternate representation.
     let alternate = if matches!(s.chars().next(), Some('#')) {
@@ -65,7 +83,7 @@ fn parse_display_hint(mut s: &str) -> Option<DisplayHint> {
         false
     };
 
-    let zero_pad = if let Some(rest) = s.strip_prefix("0") {
+    let zero_pad = if let Some(rest) = s.strip_prefix('0') {
         let (rest, columns) = parse_integer::<usize>(rest)?;
         s = rest;
         columns
@@ -73,9 +91,25 @@ fn parse_display_hint(mut s: &str) -> Option<DisplayHint> {
         0 // default behavior is the same as no zero-padding.
     };
 
+    if let Some(stripped) = s.strip_prefix(BITFLAGS_HINT_START) {
+        let parts = stripped.split('@').collect::<Vec<_>>();
+        match *parts {
+            [bitflags_name, package, disambiguator] => {
+                return Some(DisplayHint::Bitflags {
+                    name: bitflags_name.into(),
+                    package: package.into(),
+                    disambiguator: disambiguator.into(),
+                });
+            }
+            _ => {
+                return Some(DisplayHint::Unknown(s.into()));
+            }
+        }
+    }
+
     Some(match s {
         "" => DisplayHint::NoHint { zero_pad },
-        "µs" => DisplayHint::Microseconds,
+        "us" => DisplayHint::Microseconds,
         "a" => DisplayHint::Ascii,
         "b" => DisplayHint::Binary {
             alternate,
@@ -91,6 +125,8 @@ fn parse_display_hint(mut s: &str) -> Option<DisplayHint> {
             uppercase: true,
             zero_pad,
         },
+        "iso8601ms" => DisplayHint::ISO8601(TimePrecision::Millis),
+        "iso8601s" => DisplayHint::ISO8601(TimePrecision::Seconds),
         "?" => DisplayHint::Debug,
         _ => return None,
     })
@@ -124,7 +160,7 @@ pub enum Fragment<'f> {
 ///
 /// format_spec := [ zero_pad ] type
 /// zero_pad := '0' integer
-/// type := 'a' | 'b' | 'o' | 'x' | 'X' | '?' | 'µs'
+/// type := 'a' | 'b' | 'o' | 'x' | 'X' | '?' | 'us'
 /// ```
 #[derive(Debug, PartialEq)]
 struct Param {
@@ -661,6 +697,24 @@ mod tests {
             })
         );
 
+        assert_eq!(
+            parse_param(":iso8601ms", ParserMode::Strict),
+            Ok(Param {
+                index: None,
+                ty: Type::Format,
+                hint: Some(DisplayHint::ISO8601(TimePrecision::Millis)),
+            })
+        );
+
+        assert_eq!(
+            parse_param(":iso8601s", ParserMode::Strict),
+            Ok(Param {
+                index: None,
+                ty: Type::Format,
+                hint: Some(DisplayHint::ISO8601(TimePrecision::Seconds)),
+            })
+        );
+
         assert_eq!(
             parse_param(":?", ParserMode::Strict),
             Ok(Param {
@@ -763,15 +817,6 @@ mod tests {
             })
         );
 
-        assert_eq!(
-            parse_param("=u24", ParserMode::Strict),
-            Ok(Param {
-                index: None,
-                ty: Type::U24,
-                hint: None,
-            })
-        );
-
         assert_eq!(
             parse_param("=u32", ParserMode::Strict),
             Ok(Param {
@@ -799,6 +844,15 @@ mod tests {
             })
         );
 
+        assert_eq!(
+            parse_param("=u128:iso8601s", ParserMode::Strict),
+            Ok(Param {
+                index: None,
+                ty: Type::U128,
+                hint: Some(DisplayHint::ISO8601(TimePrecision::Seconds)),
+            })
+        );
+
         assert_eq!(
             parse_param("=f32", ParserMode::Strict),
             Ok(Param {
